<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="he" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>מדור:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>התחל טורנט</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>דלג על בדיקת גיבוב</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>צור תיקיית משנה</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>מצב ניהול טורנטים:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>הכל</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>בלתי ממודר</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>הוסף מדור...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>הסר מדור</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>הסר מדורים שאינם בשימוש</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>המשך טורנטים</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>השהה טורנטים</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>מחק טורנטים</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>קטגוריה חדשה</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>ערוך קטגוריה...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>צא מ-qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>קישור אחד בלבד לכל שורה</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>מגבלה עולמית של קצב העלאה חייבת להיות גדולה מ-0 או מושבתת.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>מגבלה עולמית של קצב הורדה חייבת להיות גדולה מ-0 או מושבתת.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>מגבלת קצב חלופי של העלאה חייבת להיות גדולה מ-0 או מושבתת.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>מגבלת קצב חלופי של הורדה חייבת להיות גדולה מ-0 או מושבתת.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>הורדות פעילות מרביות חייבות להיות גדולות מ-(-1).</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>העלאות פעילות מרביות חייבות להיות גדולות מ-(-1).</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>טורנטים פעילים מרביים חייבים להיות גדולים מ-(-1).</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>מספר מרבי של מגבלת חיבורים חייב להיות גדול מ-0 או מושבת.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>מספר מרבי של מגבלת חיבורים לכל טורנט חייב להיות גדול מ-0 או מושבת.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>מספר מרבי של מגבלת חריצי העלאה לכל טורנט חייב להיות גדול מ-0 או מושבת.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>לא ניתן לשמור את העדפות התכנית, qBittorrent כנראה בלתי נגיש.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: ערוץ #qbittorrent על Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>לא ידוע</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>מגבלת יחס שיתוף חייבת להיות בין 0 לבין 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>מגבלת זמן זריעה חייבת להיות בין 0 לבין 525600 דקות.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>הפתחה המשמשת לחיבורים נכנסים חייבת להיות בין 1 ל-65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>הפתחה המשמשת לממשק משתמש הרשת חייבת להיות בין 1 ל-65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>לא ניתן היה להיכנס, qBittorrent כנראה בלתי נגיש.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>שם משתמש או סיסמה לא תקפים.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>שם משתמש</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>סיסמה</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>היכנס</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>מחברים מקוריים</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>החל</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>העלה טורנטים</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>שמור קבצים במיקום:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>עוגייה:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>הקלד תיקייה כאן</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>עוד מידע</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>מידע על אישורים</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>הגדר מיקום</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>הגבל קצב העלאה</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>הגבל קצב הורדה</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>שנה שם טורנט</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>אחר...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>יום שני</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>יום שלישי</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>יום רביעי</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>יום חמישי</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>יום שישי</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>שבת</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>יום ראשון</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>התנתק</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>הורד טורנטים מהכתובות או מקישורי המגנט שלהם</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>העלה טורנט מקומי</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>האם אתה בטוח שברצונך למחוק את הטורנטים הנבחרים מרשימת ההעברות?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>לקוח qBittorrent בלתי נגיש</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>מספר עולמי של מגבלת חריצי העלאה חייב להיות גדול מ־0 או מושבת.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>שם בלתי תקף של קטגוריה:\nאנא אל תשתמש בתווים מיוחדים כלשהם בשם הקטגוריה.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>לא היה ניתן ליצור קטגוריה</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>סף קצב העלאה חייב להיות גדול מ־0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>עריכה</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>שטח פנוי: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>קוצב־זמן של אי־פעילות טורנט חייבת להיות גדול מ־0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>ניהול שמירה</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>סף קצב הורדה חייב להיות גדול מ־0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent כובה</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>עריכה</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>כלים</translation>
    </message>
    <message>
        <source>File</source>
        <translation>קובץ</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>עזרה</translation>
    </message>
    <message>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>אפשרויות...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>המשך</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>עדיפות מזערית</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>עדיפות עליונה</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>הפחת עדיפות</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>הגבר עדיפות</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>סרגל כלים עליון</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>שורת מיצב</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>מהירות בשורת הכותרת</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>תרום!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>המשך הכל</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>סטטיסטיקה</translation>
    </message>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>השהה</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>השהה הכל</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>הוסף קובץ טורנט...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>תיעוד</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>הוסף קישור טורנט...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>כן</translation>
    </message>
    <message>
        <source>No</source>
        <translation>לא</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>מגבלה עולמית של מהירות העלאה</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>מגבלה עולמית של מהירות הורדה</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>האם אתה בטוח שאתה רוצה לצאת מ-qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[הור: %1, העל: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>מגבלות מהירות חלופיות</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>מנוע חיפוש</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>סנן רשימת טורנטים...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>העברות</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>חיבור</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>מהירות</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>ביטורנט</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>ממשק רשת</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>שפה</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>שפת ממשק משתמש:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>התראת דוא"ל בעת השלמת הורדה</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>הרץ תכנית חיצונית בעת השלמת טורנט</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>סינון IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>תזמן את השימוש במגבלות קצב חלופי</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>תור טורנטים</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>זרע טורנטים עד שזמן זריעתם מגיע אל</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>הוסף באופן אוטומטי גששים אלו להורדות חדשות:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>ממשק משתמש של רשת (שלט רחוק)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>:כתובת IP</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>תחומי שרת:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>השתמש ב-HTTPS במקום ב-HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>עקוף אימות עבור לקוחות על localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>עקוף אימות עבור לקוחות אשר בתת-רשתות IP ברשימה לבנה</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>עדכן את השם של התחום הדינמי שלי</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>שמור טורנטים בלתי שלמים ב:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>העתק קבצי .torrent אל:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>העתק קבצי torrent. עבור הורדות שהסתיימו אל:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>הקצה מראש מקום בכונן עבור כל הקבצים</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>הוסף סיומת .!qB לקבצים בלתי שלמים</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>הוסף טורנטים באופן אוטומטי מ:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>שרת SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>שרת זה דורש חיבור מאובטח (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>אימות</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>שם משתמש:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>סיסמה:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>פרוטוקול מאופשר:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP ו-μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>פתחת האזנה</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>פתחה המשמשת לחיבורים נכנסים:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>השתמש בקידום פתחות UPnP / NAT-PMP מהנתב שלי</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>השתמש בפתחה שונה בכל הזנק</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>מגבלות חיבורים</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>מספר מרבי של חיבורים לכל טורנט:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>מספר מרבי עולמי של חיבורים:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>מספר מרבי של חריצי העלאה לכל טורנט:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>מספר מרבי עולמי של חריצי העלאה:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>שרת ייפוי כוח</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>סוג:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(כלום)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>מארח:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>פתחה:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>השתמש בייפוי כוח עבור חיבורי עמיתים</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>השבת חיבורים שאינם נתמכים ע"י ייפויי כוח</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>השתמש בייפוי כוח רק לטורנטים</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>נתיב מסנן (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>כתובות IP שהוחרמו באופן ידני...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>החל על גששים</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>מגבלות קצב עולמי</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>העלאה:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>הורדה:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>מגבלות קצב חלופי</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>מ:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>אל:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>מתי:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>כל יום</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>ימי חול</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>סופי שבוע</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>הגדרות מגבלות קצב</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>החל מגבלת קצב על תקורת תעבורה</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>החל מגבלת קצב על פרוטוקול µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>פרטיות</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>אפשר DHT (רשת מבוזרת) כדי למצוא יותר עמיתים</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>אפשר החלפת עמיתים (PeX) כדי למצוא יותר עמיתים</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>אפשר גילוי עמיתים מקומיים כדי למצוא יותר עמיתים</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>מצב הצפנה:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>העדף הצפנה</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>דרוש הצפנה</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>השבת הצפנה</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>אפשר מצב אלמוני</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>הורדות פעילות מרביות:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>העלאות פעילות מרביות:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>טורנטים פעילים מרביים:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>אל תחשיב טורנטים איטיים במגבלות אלו</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>הגבלת יחס שיתוף</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>זרע טורנטים עד שיחסם מגיע אל</translation>
    </message>
    <message>
        <source>then</source>
        <translation>לאחר מכן</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>השהה אותם</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>הסר אותם</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>השתמש ב-UPnP / NAT-PMP כדי להעביר הלאה את הפתחה מהנתב שלי</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>אישור:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>מפתח:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>הירשם</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>שם תחום:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>פרמטרים נתמכים (תלוי רישיות):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: שם טורנט</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: מדור</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: תגיות (מופרדות ע"י פסיק)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: נתיב תוכן (זהה לנתיב שורש עבור טורנט  מרובה קבצים)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: נתיב שורש (תחילה נתיב תיקיית משנה של טורנט)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: נתיב שמירה</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: מספר קבצים</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: גודל טורנט (בתים)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: גשש נוכחי</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: גיבוב מידע</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>עצה: תמצת פרמטר בעזרת סימני ציטוט כדי למנוע ממלל להיחתך בשטח לבן (לדוגמה, "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>שם המשתמש של ממשק הרשת חייב להיות באורך של 3 תוים לפחות.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>הסיסמה של ממשק הרשת חייבת להיות באורך של 6 תוים לפחות.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>דקות</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>ק"ב/ש</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>אפשר הגנה מפני מחטף לחיצה</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>אפשר הגנה מפני זיוף בקשות חוצות־אתרים (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>מחק קבצי טורנט לאחר מכן</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>סף קצב הורדה:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>סף קצב העלאה:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>שנה סיסמה נוכחית</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>אוטומטי</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>השתמש בממשק רשת חלופי</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>נתיב שמירה ברירת מחדל:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>המיקום החלופי של קבצי ממשק משתמש רשת אינו יכול להיות ריק.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>אל תתחיל את ההורדה באופן אוטומטי</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>החלף טורנט למצב ידני</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>כאשר קטגורית טורנט השתנתה:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>מקם מחדש טורנטים מושפעים</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>החל מגבלת קצב על עמיתים ב־LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 אומר בלתי מוגבל</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>מקם מחדש טורנט</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>כאשר נתיב ברירת מחדל של שמירה השתנה:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>אפשר תיקוף של כותרת מארח</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>אבטחה</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>כאשר נתיב שמירת קטגוריה השתנה:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>צור תיקיית משנה עבור טורנטים עם קבצים רבים</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>שניות</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>החלף טורנטים מושפעים למצב ידני</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>מיקום קבצים:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ידני</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>קוצב־זמן של אי־פעילות טורנט:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>מצב ברירת מחדל של ניהול טורנטים:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>בעת הוספת טורנט</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>פתחה</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>דגלים</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>חיבור</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>לקוח</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>התקדמות</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>מהירות הורדה</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>מהירות העלאה</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>ירד</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>הועלה</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>רלוונטיות</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>קבצים</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>מדינה</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>רגיל</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>גבוה</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>מירב</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>כללי</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>גששים</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>עמיתים</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>מקורות HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>תוכן</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>ירד:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>העברה</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>משך זמן פעיל:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>זמן משוער שנותר:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>הועלה:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>זורעים:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>מהירות הורדה:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>מהירות העלאה:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>עמיתים:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>מגבלת הורדה:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>מגבלת העלאה:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>בוזבז:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>חיבורים:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>מידע</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>הערה:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>יחס שיתוף:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>הכרז מחדש בעוד:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>נראה לאחרונה שלם:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>גודל כולל:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>חתיכות:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>נוצר ע"י:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>התווסף ב:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>הושלם ב:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>נוצר ב:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>גיבוב טורנט:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>נתיב שמירה:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>אף פעם</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (יש %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 שיח נוכחי)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 מירב)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 סה"כ)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 ממוצע)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>מגבלת הורדה:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>מגבלת העלאה:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>תיקייה מנוטרת</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>דרוס מיקום שמירה</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>תיקייה מנוטרת</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>מיקום שמירה ברירת מחדל</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>ק"ב/ש</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>סטטיסטיקה</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>סטטיסטיקת משתמש</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>סטטיסטיקת מטמון</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>לחיצות מטמון קריאה:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>זמן ממוצע בתור:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>עמיתים מחוברים:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>יחס שיתוף של כל הזמנים:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>הורדה של כל הזמנים:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>בזבוז שיח:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>העלאה של כל הזמנים:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>סה"כ גודל מאגר:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>סטטיסטיקת ביצועים</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>משרות ק/פ בתור:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>עומס יתר מטמון כתיבה:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>עומס יתר מטמון קריאה:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>גודל בתור כולל:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 צמתים</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>הכל (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>מוריד (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>זורע (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>הושלם (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>מומשך (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>מושהה (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>פעיל (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>לא פעיל (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>נתקל בשגיאה (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>הכל (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>מוריד (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>זורע (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>הושלם (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>מושהה (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>מומשך (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>פעיל (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>לא פעיל (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>נתקל בשגיאה (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>התקדמות</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>עדיפות הורדה</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>נותר</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>זמינות</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>שם</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>גודל</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>בוצע</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>מיצב</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>זורעים</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>עמיתים</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>מהירות הורדה</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>מהירות העלאה</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>יחס</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>זמן משוער שנותר</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>מדור</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>תגיות</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>התווסף בתאריך</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>הושלם בתאריך</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>גשש</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>מגבלת הורדה</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>מגבלת העלאה</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>ירד</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>הועלה</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>הורדה בשיח</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>העלאה בשיח</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>נותר</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>משך זמן פעיל</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>נתיב שמירה</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>הושלמו</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>מגבלת יחס</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>נראה לאחרונה שלם</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>פעילות אחרונה</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>גודל כולל</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>כתובת</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>מיצב</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>עמיתים</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>הודעה</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>ירד</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>כתובת גשש:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>מעדכן...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>עובד</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>מושבת</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>לא נוצר קשר עדין</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>לא זמין</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>זורעים</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>לא עובד</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>העתק כתובת גשש</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>הוסף גשש חדש...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>ערוך כתובת גשש...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>עריכת גשש</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>עלוקות</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>הסר גשש</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>דו שיח הוספת גששים</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>רשימת גששים להוספה (אחד לשורה):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 קודם לכן</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>מקצה</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>מושהה</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>הושלם</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>מעביר</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[א] זורע</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>זורע</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>בתור</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>נתקל בשגיאה</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[א] מוריד</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>מוריד מטא־נתונים</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>בודק</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>קבצים חסרים</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>בתור לבדיקה</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>מוריד</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>בודק נתוני המשכה</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>ממתין</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>מיצב</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>מדורים</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>הגבלת מהירות הורדה של טורנט</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>הגבלת מהירות העלאה של טורנט</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>שינוי שם</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>המשך</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>אלץ המשכה</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>השהה</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>הגבל יחס שיתוף...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>הגבל קצב העלאה...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>הגבל קצב הורדה...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>הזז למעלה</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>הזז למטה</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>הזז לראש</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>הזז לתחתית</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>הגדר מיקום...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>העתק שם</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>העתק גיבוב</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>הורד חתיכה ראשונה ואחרונה תחילה</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>ניהול טורנטים אוטומטי</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>מדור</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>חדש...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>אפס</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>עדיפות</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>אלץ בדיקה חוזרת</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>העתק קישור מגנט</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>מצב זריעת-על</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>שנה שם...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>הורד בסדר עוקב</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>אלץ בדיקה חוזרת</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>קטגוריה חדשה</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>מיקום</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>שם חדש</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>קבע מיקום</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>אלץ הכרזה מחדש</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>ערוך קטגוריה</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>נתיב שמירה</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>הגבלת יחס העלאה/הורדה של טורנט</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>השתמש במגבלת שיתוף עולמית</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>אל תגדיר מגבלת שיתוף</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>הגדר מגבלת שיתוף אל</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>יחס</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>דקות</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>לקוח BitTorrent מתקדם המתוכנת ב-C++, מבוסס על ערכת כלים Qt ו-libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>דף הבית:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>קבוצת דיון:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>גשש תקלים:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>אישור מחיקה</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>מחק את הקבצים גם מהכונן הקשיח</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>אישור מחיקה - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>הורד מכתובות</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>הורדה</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>הוסף קישורי טורנט</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>ב</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>ק"ב</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>מ"ב</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>ג"ב</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>ט"ב</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>פ"ב</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>ה"ב</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/ש</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 ש' %2 ד'</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 י' %2 ש'</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>לא ידוע</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>פחות מדקה</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 דקות</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>נתיב השמירה ריק</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>בטל</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>נתיב מתקע:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>כתובת או תיקייה מקומית</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>התקן מתקע</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>אישור</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>זורעים:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>כל המתקעים</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>עצור</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>מתקעי חיפוש...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>כל הקטגוריות</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>חפש ב:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>העתק את כתובת דף התיאור</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>עבור לדף התיאור</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>תוצאות (מראה</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>הורד</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>סנן</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>שמות טורנט בלבד</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>רק מאופשרים</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>מתוך</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>בכל מקום</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>הסר</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>התקן מתקע חדש</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>אתה יכול להשיג מתקעי מנוע חיפוש חדשים כאן:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>סגור</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>מתקעי חיפוש מותקנים:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>מאופשר</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>אזהרה: הייה בטוח להיענות לחוקי זכויות היוצרים של מדינתך בעת הורדת טורנטים מכל אחד ממנועי חיפוש אלו.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>בדוק אחר עדכונים</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>מתקעי חיפוש</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>עלוקות</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>מנוע חיפוש</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>זורעים</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>כתובת אתר</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>מאופשר</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>גרסה</translation>
    </message>
</context>
</TS>